@@ -1,7 +1,7 @@
 package Perinci::Sub::PropertyUtil;
 
-our $DATE = '2016-01-07'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-05-10'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,21 +21,21 @@ sub declare_property {
 
     $name =~ m!\A((result|args/\*)/)?\w+\z! or die "Invalid property name";
 
-    # insert the property's schema into Sah::Schema::Rinci
+    # insert the property's schema into Sah::Schema::rinci::function_meta
     {
-        require Sah::Schema::Rinci;
-        my $p = $Sah::Schema::Rinci::SCHEMAS{rinci_function}[1]{_prop}
-            or die "BUG: Schema structure changed (1)";
+        require Sah::Schema::rinci::function_meta;
+        my $p = $Sah::Schema::rinci::function_meta::schema->[1]{_prop}
+            or die "BUG: Schema structure changed (1a)";
 
         my $n;
         if ($name =~ m!\Aresult/(.+)!) {
             $n = $1;
             $p = $p->{result}{_prop}
-                or die "BUG: Schema structure changed (2)";
+                or die "BUG: Schema structure changed (2a)";
         } elsif ($name =~ m!\Aargs/\*/(.+)!) {
             $n = $1;
             $p = $p->{args}{_value_prop}
-                or die "BUG: Schema structure changed (3)";
+                or die "BUG: Schema structure changed (3a)";
         } else {
             $n = $name;
         }
@@ -95,7 +95,7 @@ Perinci::Sub::PropertyUtil - Utility routines for Perinci::Sub::Property::* modu
 
 =head1 VERSION
 
-This document describes version 0.10 of Perinci::Sub::PropertyUtil (from Perl distribution Perinci-Sub-PropertyUtil), released on 2016-01-07.
+This document describes version 0.11 of Perinci::Sub::PropertyUtil (from Perl distribution Perinci-Sub-PropertyUtil), released on 2016-05-10.
 
 =head1 SYNOPSIS
 
@@ -103,19 +103,13 @@ This document describes version 0.10 of Perinci::Sub::PropertyUtil (from Perl di
 
 =head2 declare_property
 
-=head1 SEE ALSO
-
-L<Perinci>
-
-Perinci::Sub::Property::* modules.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-PropertyUtil>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-PropertyUtil>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-PropertyUtil>.
 
 =head1 BUGS
 
@@ -125,6 +119,12 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci>
+
+Perinci::Sub::Property::* modules.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
